@@ -29,6 +29,7 @@ const (
 
 type function struct {
 	argcount int
+	iter     bool
 	callback func(interface{}, []interface{}) interface{}
 }
 
@@ -42,8 +43,6 @@ func init() {
 	internalFuncs = map[string]function{
 		"empty":          argFunc0(nil),
 		"path":           argFunc1(nil),
-		"debug":          argFunc0(nil),
-		"stderr":         argFunc0(nil),
 		"env":            argFunc0(nil),
 		"builtins":       argFunc0(nil),
 		"input":          argFunc0(nil),
@@ -60,7 +59,7 @@ func init() {
 		"contains":       argFunc1(funcContains),
 		"explode":        argFunc0(funcExplode),
 		"implode":        argFunc0(funcImplode),
-		"split":          {argcount1 | argcount2, funcSplit},
+		"split":          {argcount1 | argcount2, false, funcSplit},
 		"tojson":         argFunc0(funcToJSON),
 		"fromjson":       argFunc0(funcFromJSON),
 		"format":         argFunc1(funcFormat),
@@ -172,16 +171,16 @@ func init() {
 		"strptime":       argFunc1(funcStrptime),
 		"now":            argFunc0(funcNow),
 		"_match":         argFunc3(funcMatch),
-		"error":          {argcount0 | argcount1, funcError},
+		"error":          {argcount0 | argcount1, false, funcError},
 		"halt":           argFunc0(funcHalt),
-		"halt_error":     {argcount0 | argcount1, funcHaltError},
+		"halt_error":     {argcount0 | argcount1, false, funcHaltError},
 		"_type_error":    argFunc1(internalfuncTypeError),
 	}
 }
 
 func argFunc0(fn func(interface{}) interface{}) function {
 	return function{
-		argcount0, func(v interface{}, _ []interface{}) interface{} {
+		argcount0, false, func(v interface{}, _ []interface{}) interface{} {
 			return fn(v)
 		},
 	}
@@ -189,7 +188,7 @@ func argFunc0(fn func(interface{}) interface{}) function {
 
 func argFunc1(fn func(interface{}, interface{}) interface{}) function {
 	return function{
-		argcount1, func(v interface{}, args []interface{}) interface{} {
+		argcount1, false, func(v interface{}, args []interface{}) interface{} {
 			return fn(v, args[0])
 		},
 	}
@@ -197,7 +196,7 @@ func argFunc1(fn func(interface{}, interface{}) interface{}) function {
 
 func argFunc2(fn func(interface{}, interface{}, interface{}) interface{}) function {
 	return function{
-		argcount2, func(v interface{}, args []interface{}) interface{} {
+		argcount2, false, func(v interface{}, args []interface{}) interface{} {
 			return fn(v, args[0], args[1])
 		},
 	}
@@ -205,7 +204,7 @@ func argFunc2(fn func(interface{}, interface{}, interface{}) interface{}) functi
 
 func argFunc3(fn func(interface{}, interface{}, interface{}, interface{}) interface{}) function {
 	return function{
-		argcount3, func(v interface{}, args []interface{}) interface{} {
+		argcount3, false, func(v interface{}, args []interface{}) interface{} {
 			return fn(v, args[0], args[1], args[2])
 		},
 	}
@@ -1591,13 +1590,7 @@ func toInt(x interface{}) (int, bool) {
 	case int:
 		return x, true
 	case float64:
-		if minInt <= x && x <= maxInt {
-			return int(x), true
-		}
-		if x > 0 {
-			return maxInt, true
-		}
-		return minInt, true
+		return floatToInt(x), true
 	case *big.Int:
 		if x.IsInt64() {
 			if i := x.Int64(); minInt <= i && i <= maxInt {
@@ -1613,6 +1606,16 @@ func toInt(x interface{}) (int, bool) {
 	}
 }
 
+func floatToInt(x float64) int {
+	if minInt <= x && x <= maxInt {
+		return int(x)
+	}
+	if x > 0 {
+		return maxInt
+	}
+	return minInt
+}
+
 func toFloat(x interface{}) (float64, bool) {
 	switch x := x.(type) {
 	case int:
